Corresponding Chromaticities
============================

Prediction
----------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    corresponding_chromaticities_prediction
    CORRESPONDING_CHROMATICITIES_PREDICTION_MODELS
    CorrespondingColourDataset
    CorrespondingChromaticitiesPrediction

**Dataset**

``colour``

.. autosummary::
    :toctree: generated/

    BRENEMAN_EXPERIMENTS
    BRENEMAN_EXPERIMENT_PRIMARIES_CHROMATICITIES

Fairchild (1990)
~~~~~~~~~~~~~~~~

``colour.corresponding``

.. currentmodule:: colour.corresponding

.. autosummary::
    :toctree: generated/

    corresponding_chromaticities_prediction_Fairchild1990

CIE 1994
~~~~~~~~

``colour.corresponding``

.. currentmodule:: colour.corresponding

.. autosummary::
    :toctree: generated/

    corresponding_chromaticities_prediction_CIE1994

CMCCAT2000
~~~~~~~~~~

``colour.corresponding``

.. currentmodule:: colour.corresponding

.. autosummary::
    :toctree: generated/

    corresponding_chromaticities_prediction_CMCCAT2000

Von Kries
~~~~~~~~~

``colour.corresponding``

.. currentmodule:: colour.corresponding

.. autosummary::
    :toctree: generated/

    corresponding_chromaticities_prediction_VonKries
